@@ -13,15 +13,15 @@
 % GNU General Public License for more details.
 %
 % You should have received a copy of the GNU Affero General Public License
-% along with this program.  If not, see <http://www.gnu.org/licenses/>.
+% along with this program.  If not, see <https://www.gnu.org/licenses/>.
 %
 % Additional Permission under GNU AGPL version 3 section 7:
 %
 % If you modify this Program, or any covered work, by linking or
 % combining it with runtime libraries of Erlang/OTP as released by
-% Ericsson on http://www.erlang.org (or a modified version of these
+% Ericsson on https://www.erlang.org (or a modified version of these
 % libraries), containing parts covered by the terms of the Erlang Public
-% License (http://www.erlang.org/EPLICENSE), the licensors of this
+% License (https://www.erlang.org/EPLICENSE), the licensors of this
 % Program grant you additional permission to convey the resulting work
 % without the need to license the runtime libraries of Erlang/OTP under
 % the GNU Affero General Public License. Corresponding Source for a
@@ -50,20 +50,17 @@
 
 % Diameter application definitions
 
--define(DIA_STATS_TAB, iwf_stats).
--define(DIA_STATS_COUNTERS, [event_OK, event_ERR]).
-
 -define(SVC_NAME, ?MODULE).
 -define(APP_ALIAS, ?MODULE).
 -define(CALLBACK_MOD, server_cb).
 -define(DIAMETER_DICT_HSS, diameter_3gpp_ts29_272).
 
--define(APPID_S6, #'diameter_base_Vendor-Specific-Application-Id'{'Vendor-Id'=10515, 'Auth-Application-Id'=[16777251]}).
+-define(APPID_S6, #'diameter_base_Vendor-Specific-Application-Id'{'Vendor-Id'=10415, 'Auth-Application-Id'=[16777251]}).
 -define(SERVICE(Name), [{'Origin-Host', application:get_env(osmo_dia2gsup, origin_host, "hss.localdomain")},
 			{'Origin-Realm', application:get_env(osmo_dia2gsup, origin_realm, "localdomain")},
 			{'Vendor-Id', application:get_env(osmo_dia2gsup, vendor_id, 0)},
 			{'Origin-State-Id', diameter:origin_state_id()},
-			{'Product-Name', "osmo_dia2gsup"},
+			{'Product-Name', Name},
 			{'Auth-Application-Id', []},
 			{'Vendor-Specific-Application-Id', [?APPID_S6]},
 			{application,
@@ -99,8 +96,7 @@ main(_Args) ->
 %% @callback gen_server
 init(State) ->
 	% DIAMETER side
-	SvcName = ?MODULE,
-	diameter:start_service(SvcName, ?SERVICE(SvcName)),
+	diameter:start_service(?SVC_NAME, ?SERVICE(?MODULE)),
 
 	Ip = application:get_env(osmo_dia2gsup, diameter_ip, "127.0.0.8"),
 	Port = application:get_env(osmo_dia2gsup, diameter_port, 3868),
